
#ifndef HIPSPARSELT_EXPORT_H
#define HIPSPARSELT_EXPORT_H

#ifdef HIPSPARSELT_STATIC_DEFINE
#  define HIPSPARSELT_EXPORT
#  define HIPSPARSELT_NO_EXPORT
#else
#  ifndef HIPSPARSELT_EXPORT
#    ifdef hipsparselt_EXPORTS
        /* We are building this library */
#      define HIPSPARSELT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define HIPSPARSELT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef HIPSPARSELT_NO_EXPORT
#    define HIPSPARSELT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef HIPSPARSELT_DEPRECATED
#  define HIPSPARSELT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef HIPSPARSELT_DEPRECATED_EXPORT
#  define HIPSPARSELT_DEPRECATED_EXPORT HIPSPARSELT_EXPORT HIPSPARSELT_DEPRECATED
#endif

#ifndef HIPSPARSELT_DEPRECATED_NO_EXPORT
#  define HIPSPARSELT_DEPRECATED_NO_EXPORT HIPSPARSELT_NO_EXPORT HIPSPARSELT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef HIPSPARSELT_NO_DEPRECATED
#    define HIPSPARSELT_NO_DEPRECATED
#  endif
#endif

#endif /* HIPSPARSELT_EXPORT_H */
